@@ -77,7 +77,7 @@ class WebCoverageService_1_1_0(WCSBase):
             #non-hierarchical.
             top=None
             for elem in self._capabilities.findall('{http://www.opengis.net/wcs/1.1}Contents/{http://www.opengis.net/wcs/1.1}CoverageSummary'):     
-                cm=ContentMetadata(elem, top)
+                cm=ContentMetadata(elem, top, self)
                 #make the describeCoverage requests to populate the supported formats/crs attributes
                 self.contents[cm.id]=cm
 
@@ -123,7 +123,9 @@ class WebCoverageService_1_1_0(WCSBase):
         if store = true, returns a coverages XML file
         if store = false, returns a multipart mime
         """
-
+        self.log.debug('WCS 1.1.0 DEBUG: Parameters passed to GetCoverage: identifier=%s, bbox=%s, time=%s, format=%s,        rangesubset=%s, gridbaseCRS=%s, gridtype=%s, gridCS=%s, gridorigin=%s, gridoffsets=%s, method=%s, other_arguments=%s'%(identifier, bbox, time, format, rangesubset, gridbaseCRS, gridtype, gridCS, gridorigin, gridoffsets, method, str(kwargs)))
+        
+        
         if method == 'Get':
             method='{http://www.opengis.net/wcs/1.1/ows}Get'
         base_url = self.getOperationByName('GetCoverage').methods[method]['url']
@@ -164,23 +166,33 @@ class WebCoverageService_1_1_0(WCSBase):
         
         #encode and request
         data = urlencode(request)
+        #u = urlopen(base_url+data)
+        self.log.debug('WCS 1.1.0 DEBUG: base url of server: %s'%base_url)
+        self.log.debug('WCS 1.1.0 DEBUG: second part of URL: %s'%data)      
         try:
-            u = urlopen(base_url, data=data)
-        except:
-            u = urlopen(base_url+dat)
+            u = urlopen(base_url + data) 
+            self.log.debug('WCS 1.1.0 DEBUG: called urlopen(base_url+data)')            
+        except:   
+            u = urlopen(base_url,data)
+            self.log.debug('WCS 1.1.0 DEBUG: called urlopen(base_url, data)')
+            
+        
+        self.log.debug('WCS 1.1.0 DEBUG: GetCoverage request made: %s'%u.url)
+        self.log.debug('WCS 1.1.0 DEBUG: Headers returned: %s'%str(u.headers))
                 
         # check for service exceptions, and return
-        if u.info()['Content-Type'] == 'text/xml':          
-            #going to have to read the xml to see if it's an exception report.
-            #wrap the url stram in a extended StringIO object so it's re-readable
-            u=RereadableURL(u)      
-            se_xml= u.read()
-            se_tree = etree.fromstring(se_xml)
-            serviceException=se_tree.find('{http://www.opengis.net/ows}Exception')
-            if serviceException is not None:
-                raise ServiceException, \
-                str(serviceException.text).strip()
-            u.seek(0)
+        if 'content-type' in u.info().keys():      
+            if u.info()['content-type'] == 'text/xml':          
+                #going to have to read the xml to see if it's an exception report.
+                #wrap the url stram in a extended StringIO object so it's re-readable
+                u=RereadableURL(u)      
+                se_xml= u.read()
+                se_tree = etree.fromstring(se_xml)
+                serviceException=se_tree.find('{http://www.opengis.net/ows}Exception')
+                if serviceException is not None:
+                    raise ServiceException, \
+                    str(serviceException.text).strip()
+                u.seek(0)
         return u
         
         
@@ -211,13 +223,23 @@ class ServiceIdentification(object):
         self.service="WCS"
         self.version="1.1.0"
         self.title = elem.find('{http://www.opengis.net/ows}Title').text
-        self.abstract = elem.find('{http://www.opengis.net/ows}Abstract').text
+        self.abstract=elem.find('{http://www.opengis.net/ows}Abstract').text
+        if elem.find('{http://www.opengis.net/ows}Abstract') is not None:
+            self.abstract=elem.find('{http://www.opengis.net/ows}Abstract').text
+        else:
+            self.abstract = None
         self.keywords = [f.text for f in elem.findall('{http://www.opengis.net/ows}Keywords/{http://www.opengis.net/ows}Keyword')]
         #self.link = elem.find('{http://www.opengis.net/wcs/1.1}Service/{http://www.opengis.net/wcs/1.1}OnlineResource').attrib.get('{http://www.w3.org/1999/xlink}href', '')
                
-        #NOTE: do these belong here?
-        self.fees=elem.find('{http://www.opengis.net/wcs/1.1/ows}Fees').text
-        self.accessConstraints=elem.find('{http://www.opengis.net/wcs/1.1/ows}AccessConstraints').text
+        if elem.find('{http://www.opengis.net/wcs/1.1/ows}Fees') is not None:            
+            self.fees=elem.find('{http://www.opengis.net/wcs/1.1/ows}Fees').text
+        else:
+            self.fees=None
+        
+        if  elem.find('{http://www.opengis.net/wcs/1.1/ows}AccessConstraints') is not None:
+            self.accessConstraints=elem.find('{http://www.opengis.net/wcs/1.1/ows}AccessConstraints').text
+        else:
+            self.accessConstraints=None
        
        
 class ServiceProvider(object):
@@ -315,17 +337,20 @@ class ContentMetadata(object):
                     )
                 
         # bboxes - other CRS 
-        self.boundingBoxes = []
+        self.boundingboxes = []
         for bbox in elem.findall('{http://www.opengis.net/ows}BoundingBox'):
             if bbox is not None:
-                lc=b.find('{http://www.opengis.net/ows}LowerCorner').text
-                uc=b.find('{http://www.opengis.net/ows}UpperCorner').text
-                boundingBox =  (
-                        float(lc.split()[0]),float(lc.split()[1]),
-                        float(uc.split()[0]), float(uc.split()[1]),
-                        b.attrib['crs'])
-                self.boundingBoxes.append(boundingBox)
-        
+                try:
+                    lc=b.find('{http://www.opengis.net/ows}LowerCorner').text
+                    uc=b.find('{http://www.opengis.net/ows}UpperCorner').text
+                    boundingBox =  (
+                            float(lc.split()[0]),float(lc.split()[1]),
+                            float(uc.split()[0]), float(uc.split()[1]),
+                            b.attrib['crs'])
+                    self.boundingboxes.append(boundingBox)
+                except:
+                     pass
+                
         #SupportedCRS
         self.supportedCRS=[]
         for crs in elem.findall('{http://www.opengis.net/wcs/1.1}SupportedCRS'):
@@ -336,7 +361,24 @@ class ContentMetadata(object):
         for format in elem.findall('{http://www.opengis.net/wcs/1.1}SupportedFormat'):
             self.supportedFormats.append(format.text)
             
-            
+        
+    #grid is either a gml:Grid or a gml:RectifiedGrid if supplied as part of the DescribeCoverage response.
+    def _getGrid(self):
+        grid=None
+        #TODO- convert this to 1.1 from 1.0
+        #if not hasattr(self, 'descCov'):
+                #self.descCov=self._service.getDescribeCoverage(self.id)
+        #gridelem= self.descCov.find(ns('CoverageOffering/')+ns('domainSet/')+ns('spatialDomain/')+'{http://www.opengis.net/gml}RectifiedGrid')
+        #if gridelem is not None:
+            #grid=RectifiedGrid(gridelem)
+        #else:
+            #gridelem=self.descCov.find(ns('CoverageOffering/')+ns('domainSet/')+ns('spatialDomain/')+'{http://www.opengis.net/gml}Grid')
+            #grid=Grid(gridelem)
+        return grid
+    grid=property(_getGrid, None)
+        
+        
+        
     #time limits/postions require a describeCoverage request therefore only resolve when requested
     def _getTimeLimits(self):
          timelimits=[]
@@ -347,6 +389,9 @@ class ContentMetadata(object):
     timelimits=property(_getTimeLimits, None)
     
     #TODO timepositions property
+    def _getTimePositions(self):
+        return []
+    timepositions=property(_getTimePositions, None)
     
     def _checkChildAndParent(self, path):
         ''' checks child coverage  summary, and if item not found checks higher level coverage summary'''
